/// <reference types="node" />
import { ec as EC } from "elliptic";
import { type Chain, type PublicClient, type Transport, type TypedDataDefinition } from "viem";
import type { Dex } from "./types/dex";
import type { CreateSwapRequestInput, CreateSwapRequestOutput } from "./types/smartAccountV1";
export declare class SmartAccountV1Provider {
    readonly SESSION_MANAGER_DOMAIN_NAME = "LongDefi Session Key Manager";
    readonly ecdsa: EC;
    publicClient: PublicClient<Transport, Chain>;
    dex?: Dex;
    factory?: `0x${string}`;
    sessionKeyManager?: `0x${string}`;
    constructor(publicClient: PublicClient<Transport, Chain>, factory?: `0x${string}`, sessionKeyManager?: `0x${string}`, dex?: Dex);
    setDex(dex: Dex): void;
    setFactory(factory: `0x${string}`): void;
    setSessionKeyManager(sessionKeyManager: `0x${string}`): void;
    createSessionKeyRequest(owner: `0x${string}`, smartAccountSalt: bigint): Promise<{
        sessionKey: {
            privateKey: string;
            address: `0x${string}`;
        };
        request: {
            types: {
                [x: string]: readonly import("viem").TypedDataParameter[];
                [x: `string[${string}]`]: undefined;
                [x: `function[${string}]`]: undefined;
                [x: `address[${string}]`]: undefined;
                [x: `uint256[${string}]`]: undefined;
                [x: `bool[${string}]`]: undefined;
                [x: `uint8[${string}]`]: undefined;
                [x: `uint24[${string}]`]: undefined;
                [x: `int24[${string}]`]: undefined;
                [x: `bytes[${string}]`]: undefined;
                [x: `uint160[${string}]`]: undefined;
                [x: `bytes32[${string}]`]: undefined;
                [x: `int256[${string}]`]: undefined;
                [x: `uint128[${string}]`]: undefined;
                [x: `uint96[${string}]`]: undefined;
                [x: `bytes4[${string}]`]: undefined;
                [x: `uint16[${string}]`]: undefined;
                [x: `uint32[${string}]`]: undefined;
                [x: `int56[${string}]`]: undefined;
                [x: `int16[${string}]`]: undefined;
                [x: `int128[${string}]`]: undefined;
                [x: `uint48[${string}]`]: undefined;
                [x: `uint112[${string}]`]: undefined;
                [x: `uint192[${string}]`]: undefined;
                [x: `uint64[${string}]`]: undefined;
                [x: `bytes1[${string}]`]: undefined;
                [x: `bytes3[${string}]`]: undefined;
                [x: `bytes2[${string}]`]: undefined;
                [x: `bytes17[${string}]`]: undefined;
                [x: `bytes5[${string}]`]: undefined;
                [x: `bytes11[${string}]`]: undefined;
                [x: `bytes8[${string}]`]: undefined;
                [x: `bytes6[${string}]`]: undefined;
                [x: `bytes19[${string}]`]: undefined;
                [x: `bytes12[${string}]`]: undefined;
                [x: `bytes7[${string}]`]: undefined;
                [x: `bytes21[${string}]`]: undefined;
                [x: `bytes31[${string}]`]: undefined;
                [x: `bytes30[${string}]`]: undefined;
                [x: `bytes29[${string}]`]: undefined;
                [x: `bytes28[${string}]`]: undefined;
                [x: `bytes27[${string}]`]: undefined;
                [x: `bytes26[${string}]`]: undefined;
                [x: `bytes25[${string}]`]: undefined;
                [x: `bytes24[${string}]`]: undefined;
                [x: `bytes23[${string}]`]: undefined;
                [x: `bytes22[${string}]`]: undefined;
                [x: `bytes20[${string}]`]: undefined;
                [x: `bytes18[${string}]`]: undefined;
                [x: `bytes16[${string}]`]: undefined;
                [x: `bytes15[${string}]`]: undefined;
                [x: `bytes14[${string}]`]: undefined;
                [x: `bytes13[${string}]`]: undefined;
                [x: `bytes10[${string}]`]: undefined;
                [x: `bytes9[${string}]`]: undefined;
                [x: `int[${string}]`]: undefined;
                [x: `int8[${string}]`]: undefined;
                [x: `int40[${string}]`]: undefined;
                [x: `int32[${string}]`]: undefined;
                [x: `int48[${string}]`]: undefined;
                [x: `int64[${string}]`]: undefined;
                [x: `int72[${string}]`]: undefined;
                [x: `int80[${string}]`]: undefined;
                [x: `int88[${string}]`]: undefined;
                [x: `int96[${string}]`]: undefined;
                [x: `int104[${string}]`]: undefined;
                [x: `int112[${string}]`]: undefined;
                [x: `int120[${string}]`]: undefined;
                [x: `int136[${string}]`]: undefined;
                [x: `int144[${string}]`]: undefined;
                [x: `int152[${string}]`]: undefined;
                [x: `int160[${string}]`]: undefined;
                [x: `int168[${string}]`]: undefined;
                [x: `int176[${string}]`]: undefined;
                [x: `int184[${string}]`]: undefined;
                [x: `int192[${string}]`]: undefined;
                [x: `int200[${string}]`]: undefined;
                [x: `int208[${string}]`]: undefined;
                [x: `int216[${string}]`]: undefined;
                [x: `int224[${string}]`]: undefined;
                [x: `int232[${string}]`]: undefined;
                [x: `int240[${string}]`]: undefined;
                [x: `int248[${string}]`]: undefined;
                [x: `uint[${string}]`]: undefined;
                [x: `uint40[${string}]`]: undefined;
                [x: `uint56[${string}]`]: undefined;
                [x: `uint72[${string}]`]: undefined;
                [x: `uint80[${string}]`]: undefined;
                [x: `uint88[${string}]`]: undefined;
                [x: `uint104[${string}]`]: undefined;
                [x: `uint120[${string}]`]: undefined;
                [x: `uint136[${string}]`]: undefined;
                [x: `uint144[${string}]`]: undefined;
                [x: `uint152[${string}]`]: undefined;
                [x: `uint168[${string}]`]: undefined;
                [x: `uint176[${string}]`]: undefined;
                [x: `uint184[${string}]`]: undefined;
                [x: `uint200[${string}]`]: undefined;
                [x: `uint208[${string}]`]: undefined;
                [x: `uint216[${string}]`]: undefined;
                [x: `uint224[${string}]`]: undefined;
                [x: `uint232[${string}]`]: undefined;
                [x: `uint240[${string}]`]: undefined;
                [x: `uint248[${string}]`]: undefined;
                string?: undefined;
                address?: undefined;
                uint256?: undefined;
                bool?: undefined;
                uint8?: undefined;
                uint24?: undefined;
                int24?: undefined;
                bytes?: undefined;
                uint160?: undefined;
                bytes32?: undefined;
                int256?: undefined;
                uint128?: undefined;
                uint96?: undefined;
                bytes4?: undefined;
                uint16?: undefined;
                uint32?: undefined;
                int56?: undefined;
                int16?: undefined;
                int128?: undefined;
                uint48?: undefined;
                uint112?: undefined;
                uint192?: undefined;
                uint64?: undefined;
                bytes1?: undefined;
                bytes3?: undefined;
                bytes2?: undefined;
                bytes17?: undefined;
                bytes5?: undefined;
                bytes11?: undefined;
                bytes8?: undefined;
                bytes6?: undefined;
                bytes19?: undefined;
                bytes12?: undefined;
                bytes7?: undefined;
                bytes21?: undefined;
                bytes31?: undefined;
                bytes30?: undefined;
                bytes29?: undefined;
                bytes28?: undefined;
                bytes27?: undefined;
                bytes26?: undefined;
                bytes25?: undefined;
                bytes24?: undefined;
                bytes23?: undefined;
                bytes22?: undefined;
                bytes20?: undefined;
                bytes18?: undefined;
                bytes16?: undefined;
                bytes15?: undefined;
                bytes14?: undefined;
                bytes13?: undefined;
                bytes10?: undefined;
                bytes9?: undefined;
                int8?: undefined;
                int40?: undefined;
                int32?: undefined;
                int48?: undefined;
                int64?: undefined;
                int72?: undefined;
                int80?: undefined;
                int88?: undefined;
                int96?: undefined;
                int104?: undefined;
                int112?: undefined;
                int120?: undefined;
                int136?: undefined;
                int144?: undefined;
                int152?: undefined;
                int160?: undefined;
                int168?: undefined;
                int176?: undefined;
                int184?: undefined;
                int192?: undefined;
                int200?: undefined;
                int208?: undefined;
                int216?: undefined;
                int224?: undefined;
                int232?: undefined;
                int240?: undefined;
                int248?: undefined;
                uint40?: undefined;
                uint56?: undefined;
                uint72?: undefined;
                uint80?: undefined;
                uint88?: undefined;
                uint104?: undefined;
                uint120?: undefined;
                uint136?: undefined;
                uint144?: undefined;
                uint152?: undefined;
                uint168?: undefined;
                uint176?: undefined;
                uint184?: undefined;
                uint200?: undefined;
                uint208?: undefined;
                uint216?: undefined;
                uint224?: undefined;
                uint232?: undefined;
                uint240?: undefined;
                uint248?: undefined;
            };
        } & {
            primaryType: string;
            domain?: {
                chainId?: number | undefined;
                name?: string | undefined;
                salt?: `0x${string}` | undefined;
                verifyingContract?: `0x${string}` | undefined;
                version?: string | undefined;
            } | undefined;
            message: Record<string, unknown>;
        };
    }>;
    revokeSessionKeyRequest(owner: `0x${string}`, smartAccountSalt: bigint, pub: Uint8Array | Buffer | string | number[] | {
        x: string;
        y: string;
    } | EC.KeyPair, enc?: string): Promise<TypedDataDefinition>;
    createSwapRequest(createSwapRequestInput: CreateSwapRequestInput): Promise<CreateSwapRequestOutput>;
    getSmartAccountAddress(owner: `0x${string}`, salt: bigint): Promise<`0x${string}`>;
    getNonceForSmartAccount(smartAccount: `0x${string}`, dexFactory: `0x${string}`, tokenIn: `0x${string}`, tokenOut: `0x${string}`, fee: number, suffixId: number): Promise<bigint>;
    calculateVerificationGasLimitV1(initSmartAccount?: boolean): Promise<bigint>;
    calculateExecuteBatchGasLimit(smartAccount: `0x${string}`, dest: `0x${string}`[], value: bigint[], func: `0x${string}`[]): Promise<bigint>;
}
//# sourceMappingURL=smartAccountV1Provider.d.ts.map